@@ -26,9 +26,13 @@ class RootController(BaseController):
     rdisk = RDiskController()
     error = ErrorController()
 
-    @expose()
+    @expose('libacr.templates.page')
     def index(self, *args, **kw):
-        return redirect('/acr/index')
+        return self.acr.default(*args, **kw)
+
+    @expose()
+    def _lookup(self, *args, **kw):
+        return self.acr, args
 
     @expose('acr.templates.login')
     def login(self, came_from=url('/')):
